@@ -1,6 +1,6 @@
 //===----------------------------------------------------------------------===//
 //
-// Copyright (c) 2012, 2013, 2014, 2015, 2016 The University of Utah
+// Copyright (c) 2012, 2013, 2014, 2015, 2016, 2017 The University of Utah
 // All rights reserved.
 //
 // This file is distributed under the University of Illinois Open Source
@@ -430,7 +430,7 @@ bool RenameCXXMethod::isValidName(const StringRef &Name)
   if (!NamePrefix.equals(MethodNamePrefix))
     return false;
   llvm::APInt Num;
-  return Name.drop_front(PrefixLen).getAsInteger(10, Num);
+  return !Name.drop_front(PrefixLen).getAsInteger(10, Num);
 }
 
 void RenameCXXMethod::addOneMethodName(const CXXMethodDecl *MD,
