@@ -46,6 +46,11 @@ TransformationManager *TransformationManager::GetInstance()
   return TransformationManager::Instance;
 }
 
+Preprocessor &TransformationManager::getPreprocessor()
+{
+  return GetInstance()->ClangInstance->getPreprocessor();
+}
+
 bool TransformationManager::isCXXLangOpt()
 {
   TransAssert(TransformationManager::Instance && "Invalid Instance!");
@@ -85,17 +90,25 @@ bool TransformationManager::initializeCompilerInstance(std::string &ErrorMsg)
   
   ClangInstance->createDiagnostics();
 
+  TargetOptions &TargetOpts = ClangInstance->getTargetOpts();
+  PreprocessorOptions &PPOpts = ClangInstance->getPreprocessorOpts();
+  if (const char *env = getenv("CREDUCE_TARGET_TRIPLE")) {
+    TargetOpts.Triple = std::string(env);
+  } else {
+    TargetOpts.Triple = LLVM_DEFAULT_TARGET_TRIPLE;
+  }
+  llvm::Triple T(TargetOpts.Triple);
   CompilerInvocation &Invocation = ClangInstance->getInvocation();
   InputKind IK = FrontendOptions::getInputKindForExtension(
         StringRef(SrcFileName).rsplit('.').second);
   if ((IK == IK_C) || (IK == IK_PreprocessedC)) {
-    Invocation.setLangDefaults(ClangInstance->getLangOpts(), IK_C);
+    Invocation.setLangDefaults(ClangInstance->getLangOpts(), IK_C, T, PPOpts);
   }
   else if ((IK == IK_CXX) || (IK == IK_PreprocessedCXX)) {
     // ISSUE: it might cause some problems when building AST
     // for a function which has a non-declared callee, e.g., 
     // It results an empty AST for the caller. 
-    Invocation.setLangDefaults(ClangInstance->getLangOpts(), IK_CXX);
+    Invocation.setLangDefaults(ClangInstance->getLangOpts(), IK_CXX, T, PPOpts);
   }
   else if(IK == IK_OpenCL) {
     //Commandline parameters
@@ -121,21 +134,14 @@ bool TransformationManager::initializeCompilerInstance(std::string &ErrorMsg)
     CompilerInvocation::CreateFromArgs(Invocation,
                                        &Args[0], &Args[0] + Args.size(),
                                        ClangInstance->getDiagnostics());
-    Invocation.setLangDefaults(ClangInstance->getLangOpts(), IK_OpenCL);
+    Invocation.setLangDefaults(ClangInstance->getLangOpts(),
+                               IK_OpenCL, T, PPOpts);
   }
   else {
     ErrorMsg = "Unsupported file type!";
     return false;
   }
 
-  TargetOptions &TargetOpts = ClangInstance->getTargetOpts();
-
-  if (const char *env = getenv("CREDUCE_TARGET_TRIPLE")) {
-    TargetOpts.Triple = std::string(env);
-  } else {
-    TargetOpts.Triple = LLVM_DEFAULT_TARGET_TRIPLE;
-  }
-
   TargetInfo *Target = 
     TargetInfo::CreateTargetInfo(ClangInstance->getDiagnostics(),
                                  ClangInstance->getInvocation().TargetOpts);
@@ -165,6 +171,15 @@ bool TransformationManager::initializeCompilerInstance(std::string &ErrorMsg)
                            &ClangInstance->getPreprocessor());
   ClangInstance->createASTContext();
 
+  // It's not elegant to initialize these two here... Ideally, we 
+  // would put them in doTransformation, but we need these two
+  // flags being set before Transformation::Initialize, which
+  // is invoked through ClangInstance->setASTConsumer.
+  if (DoReplacement)
+    CurrentTransformationImpl->setReplacement(Replacement);
+  if (CheckReference)
+    CurrentTransformationImpl->setReferenceValue(ReferenceValue);
+
   assert(CurrentTransformationImpl && "Bad transformation instance!");
   ClangInstance->setASTConsumer(
     std::unique_ptr<ASTConsumer>(CurrentTransformationImpl));
@@ -350,7 +365,11 @@ TransformationManager::TransformationManager()
     OutputFileName(""),
     CurrentTransName(""),
     ClangInstance(NULL),
-    QueryInstanceOnly(false)
+    QueryInstanceOnly(false),
+    DoReplacement(false),
+    Replacement(""),
+    CheckReference(false),
+    ReferenceValue("")
 {
   // Nothing to do
 }
